.. image:: ../../_static/CSAwesomeLogo.png
    :width: 350
    :align: center

Iteration (Loops)
::::::::::::::::::::

Class Periods: 14-16 (including lab)

AP CSA Exam Weighting: 17.5-22.5%


.. toctree::
   :maxdepth: 3

   topic-4-1-while-loops.rst
   topic-4-2-for-loops.rst
   topic-4-3-strings-loops.rst
   topic-4-4-nested-loops.rst
   topic-4-5-loop-analysis.rst
   topic-4-6-summary.rst
   topic-4-6-group-mod.rst
   topic-4-7-practice-mixed-code.rst
   topic-4-7-practice-mixed-code-toggle.rst
   topic-4-8-practice-coding.rst
   Exercises.rst
   FRQcalendar.rst
   FRQselfDivisorA.rst
   FRQstringScrambleA.rst
   ConsumerReviewLab.rst
